This package is useful for debbuging.

1- use printype to print a variable and its type :)
2- use typerint to print a variable's type and itself :)
3- use printype_symbol to print a variable and its type in a new line surrounding with 80 charachters of the given symbol (default is *) :)
4- use typerint_symbol to print a variable's type and itself in a new line surrounding with 80 charachters of the given symbol (default is *) :)
